@@ -105,6 +105,28 @@ def _upload_param_stm32f407(param_path):
         raise RuntimeError("Failed to upload the params to the board")
 
 
+def _upload_param_stm32f411(param_path):
+    tools_folder = board_tools_folder(Boards.STM32F411E_DISCO)
+    programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
+
+    command = '%s --connect port=SWD ap=0' % programmer_path
+    log.debug(command)
+
+    res = subprocess.Popen(
+        command, shell=True, stderr=subprocess.STDOUT, stdout=subprocess.PIPE).stdout.read().decode('utf-8')
+    log.debug(res)
+    if 'f411x' not in res.lower():
+        raise RuntimeError("Failed to connect to the board")
+
+    magic_address = '0x08060000'
+    command = '%s --connect port=SWD ap=0 -w %s %s -hardRst' % (programmer_path, param_path, magic_address)
+    log.debug(command)
+
+    res = subprocess.run(command, **subprocess_run_kwargs).returncode
+    if res != 0:
+        raise RuntimeError("Failed to upload the params to the board")
+
+
 def _upload_param_stm32h747(param_path):
     tools_folder = board_tools_folder(Boards.STM32H747I_DISCO)
     programmer_path = os.path.join(tools_folder, 'STM32_Programmer_CLI')
@@ -137,7 +159,7 @@ def upload_params(ppn_path, rhn_path, board):
         elif board is Boards.STM32F407G_DISCO:
             _upload_param_stm32f407(param_path)
         elif board is Boards.STM32F411E_DISCO:
-            raise NotImplementedError()
+            _upload_param_stm32f411(param_path)
         elif board is Boards.STM32F469I_DISCO:
             _upload_param_stm32f469(param_path)
         elif board is Boards.STM32H747I_DISCO:
